==> types-pyaudio-0.2.16.2.tar.gz: types-pyaudio-0.2.16.2/CHANGELOG.md <==
## 0.2.16.2 (2022-11-14)

Improve `ast` types; revert several "redundant numeric union" changes from #7906 (#9130)

* Adapt number types in ast

Since mypy  0.990 type promotions was limited.
This means that complex is not longer promoted to int/float, therefore
we should adapt the types to list all possible types

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>
Co-authored-by: AlexWaygood <alex.waygood@gmail.com>

## 0.2.16.1 (2022-11-11)

Add the ability to run third-party stubtest on Windows or MacOS when needed (#8923)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 0.2.16 (2022-06-19)

stubtest: use separate table in METADATA.toml (#8096)

## 0.2.15 (2022-05-21)

Simplify and correct many numeric unions (#7906)

Unblocks PyCQA/flake8-pyi#222

## 0.2.14 (2022-05-07)

Import generics from standard modules in all third-party stubs (#7791)

## 0.2.13 (2022-04-27)

Drop Python 2 support in third-party stubs (#7703)

## 0.2.12 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 0.2.11 (2022-03-19)

PEP 604: Remove some more uses of Union/Optional (#7515)

The following patterns still break mypy:

1. `type[]` at top level fails
2. `tuple[T1, T2]` at top level fails (but `tuple[T1, ...]` is fine)
3. `T1 | Callable[..., T2 | T3]` fails, but only <=3.9

This PR cleans up usage of `Union` and `Optional` outside these patterns.

## 0.2.10 (2022-03-16)

Use PEP 604 syntax wherever possible (#7493)

## 0.2.9 (2022-01-16)

remove "= ..." from top-level values (#6930)

## 0.2.7 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 0.2.6 (2021-12-27)

Replace METADATA stubtest key with stubtest_apt_packages (#6704)

## 0.2.5 (2021-12-25)

Add a 'stubtest' flag to METADATA.toml (#6687)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 0.2.4 (2021-10-12)

Add star to all non-0.1 versions (#6146)

==> types-pyaudio-0.2.16.3.tar.gz: types-pyaudio-0.2.16.3/CHANGELOG.md <==
## 0.2.16.3 (2022-11-16)

Add missing symbols in `pyaudio` stubs (#9206)

Split off from #9187
Turned off `ignore_missing_stub` for pyaudio stubs.
Ensured it's valid for Windows and MacOS.

## 0.2.16.2 (2022-11-14)

Improve `ast` types; revert several "redundant numeric union" changes from #7906 (#9130)

* Adapt number types in ast

Since mypy  0.990 type promotions was limited.
This means that complex is not longer promoted to int/float, therefore
we should adapt the types to list all possible types

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>
Co-authored-by: AlexWaygood <alex.waygood@gmail.com>

## 0.2.16.1 (2022-11-11)

Add the ability to run third-party stubtest on Windows or MacOS when needed (#8923)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 0.2.16 (2022-06-19)

stubtest: use separate table in METADATA.toml (#8096)

## 0.2.15 (2022-05-21)

Simplify and correct many numeric unions (#7906)

Unblocks PyCQA/flake8-pyi#222

## 0.2.14 (2022-05-07)

Import generics from standard modules in all third-party stubs (#7791)

## 0.2.13 (2022-04-27)

Drop Python 2 support in third-party stubs (#7703)

## 0.2.12 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 0.2.11 (2022-03-19)

PEP 604: Remove some more uses of Union/Optional (#7515)

The following patterns still break mypy:

1. `type[]` at top level fails
2. `tuple[T1, T2]` at top level fails (but `tuple[T1, ...]` is fine)
3. `T1 | Callable[..., T2 | T3]` fails, but only <=3.9

This PR cleans up usage of `Union` and `Optional` outside these patterns.

## 0.2.10 (2022-03-16)

Use PEP 604 syntax wherever possible (#7493)

## 0.2.9 (2022-01-16)

remove "= ..." from top-level values (#6930)

## 0.2.7 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 0.2.6 (2021-12-27)

Replace METADATA stubtest key with stubtest_apt_packages (#6704)

## 0.2.5 (2021-12-25)

Add a 'stubtest' flag to METADATA.toml (#6687)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 0.2.4 (2021-10-12)

Add star to all non-0.1 versions (#6146)
